@@ -125,10 +125,10 @@ class Crp:
         customers = train_df['customerid'].unique()
         # Get the date which acts as reference point for future calculations
         dateFlag_sep = np.max(org_df['order_date']) - pd.DateOffset(months=timeFlag)
-
+        # Create a grouping aggregator
         grp = train_df.groupby('customerid')
 
-        grp_dict = {'order_date':'max','id':'count','totalprice':'sum',''}
+        grp_dict = {'order_date':'max','id':'count','totalprice':'sum','buyeracceptsmarketing':'max','billingaddresscountrycode':'unique'}
 
         df_matrix = gb.agg(d).rename(columns={'id':'num_orders'})
 
